pub fn nodes_to_partition(
analysis_results: Option<(Vec<BTreeMap<usize, StructOrTupleIndex>>, BTreeMap<usize, usize>)>,
) -> Option<HashMap<usize, StructOrTupleIndex>>Expand description
Given the set of possible partitionings, select an arbitrary one to use, and find all the parents of Network nodes that need to be modified